# BatchedResultOrganizationInvitationBase

Represents a single result in a batch of results.  Exactly one of `data` or `error` will ever be populated.
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**status** | **int** |  | 
**data** | [**OrganizationInvitationBase**](OrganizationInvitationBase.md) |  | [optional] 
**error** | [**Error**](Error.md) |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


